@@ -1,6 +1,6 @@
 package K;
 BEGIN {
-    $K::VERSION = '0.09';
+    $K::VERSION = '0.10';
 }
 use Moose;
 use namespace::autoclean;
@@ -59,9 +59,7 @@ sub _build_handle {
 sub _credentials {
     my ($self) = @_;
 
-    return '' if !$self->has_user || !$self->has_password;
-
-    return join ':', $self->user, $self->password;
+    return join ':', map { $_ // '' } $self->user, $self->password;
 }
 
 sub cmd {
@@ -115,12 +113,9 @@ K - Perl bindings for k (aka q, aka kdb, aka kx)
         timeout  => 1000,
     );
 
-    $k->cmd( '4 + 4' ); # 8
-
-    $k->cmd( q/"abc"/ ); # ['a', 'b', 'c']
-
-    $k->cmd( q/`foo`bar!(1;2)/ ); # { foo => 1, bar => 2 }
-
+    $k->cmd( '4 + 4' );                         # 8
+    $k->cmd( q/"abc"/ );                        # ['a', 'b', 'c']
+    $k->cmd( q/`foo`bar!(1;2)/ );               # { foo => 1, bar => 2 }
     $k->cmd( q/2012.03.24D12:13:14.15161728/ ); # 385906394151617280
 
     # table
@@ -157,7 +152,7 @@ the C library as faithfully as possible.
 
 C<K> returns simple Perl representations of k values.  For example, inside k
 timestamps are 64-bit ints where the value is the number of nanoseconds since
-2001.01.01D00:00:00.000 .  For such values, C<K> returns the int value (ex:
+2000.01.01D00:00:00.000 .  For such values, C<K> returns the int value (ex:
 385906394151617280).
 
 =head1 METHODS
